styx library

Classes

Component
Entity
A container that holds components essentially.
EntityMatcher
A class that describe a way to filter entities.
EntitySystem
This system is for keeping track of all created entities.

Extensions

GetXHelpersRx on Rx<T>
GetX helpers
GetXHelpersRxMixin on RxObjectMixin<T>
Helper extension on RxObjectMixins to make re-rendering widgets easy with no boilerplate needed. For example:
RxImplEntity on Rx<Entity>
RxnImplEntity on Rxn<Entity>

Functions

componentFromJson(Map<String, dynamic> json) Component?
A map of strings to types.
componentToJson(SerializableComponent component) Map<String, dynamic>
defaultEntityFromJsonFunction(Map<String, dynamic> json, EntitySystem system) Entity
defaultEntityToJsonFunction(Entity entity) Map<String, dynamic>
Standard serializer that turns an entity into JSON.

Typedefs

ComponentDeserializerFunction = Component? Function(Map<String, dynamic> data)
ComponentSerializerFunction = Map<String, dynamic> Function(SerializableComponent component)
EntityFromJsonFunction = Entity Function(Map<String, dynamic> json, EntitySystem system)
EntityToJsonFunction = Map<String, dynamic> Function(Entity entity)